Module tls

Module tls 

mTLS configuration for the admin API endpoint.

Defines AdminTlsConfig for loading server and client certificates used to authenticate admin API consumers. The actual TLS server setup happens in the consuming crate (e.g. greentic-operator via axum-server + rustls).

Structs

AdminTlsConfig
TLS configuration for the admin API endpoint.