Module cli_commands

Module cli_commands 

CLI command implementations for greentic-setup.

Functions

add
Add a pack to a bundle.
build
Build a portable bundle archive.
doctor
execute_pending_oauth_device_actions
init
Initialize a new bundle directory.
list
List packs in a bundle.
print_pending_setup_actions
remove
Remove a provider from a bundle.
setup
Run the setup command.
setup_migrate
Migrate legacy setup backend state to the generic setup state location.
setup_next
Inspect and record the next provider backend-contract setup step.
setup_reset
Reset persisted setup state for a provider backend contract.
setup_retry
Clear retry-blocking state for a provider backend-contract setup step.
setup_status
Show persisted setup status for a provider backend contract.
status
Show bundle status.
update
Run the update command.
wait_for_pending_oauth_callbacks