pub fn setup_migrate(
args: BundleSetupMigrateArgs,
_i18n: &CliI18n,
) -> Result<()>Expand description
Migrate legacy setup backend state to the generic setup state location.
pub fn setup_migrate(
args: BundleSetupMigrateArgs,
_i18n: &CliI18n,
) -> Result<()>Migrate legacy setup backend state to the generic setup state location.