pub struct SetupEngine { /* private fields */ }Expand description
The setup engine orchestrates plan → execute for bundle lifecycle.
Implementations
Sourceimpl SetupEngine
impl SetupEngine
pub fn new(config: SetupConfig) -> Self
Sourcepub fn plan(
&self,
mode: SetupMode,
request: &SetupRequest,
dry_run: bool,
) -> Result<SetupPlan>
pub fn plan( &self, mode: SetupMode, request: &SetupRequest, dry_run: bool, ) -> Result<SetupPlan>
Build a plan for the given mode and request.
Sourcepub fn print_plan(&self, plan: &SetupPlan)
pub fn print_plan(&self, plan: &SetupPlan)
Print a human-readable plan summary to stdout.
Sourcepub fn config(&self) -> &SetupConfig
pub fn config(&self) -> &SetupConfig
Access the engine configuration.
Sourcepub fn execute(&self, plan: &SetupPlan) -> Result<SetupExecutionReport>
pub fn execute(&self, plan: &SetupPlan) -> Result<SetupExecutionReport>
Execute a setup plan.
Runs each step in the plan, performing the actual bundle setup operations. Returns an execution report with details about what was done.
Sourcepub fn emit_answers(
&self,
plan: &SetupPlan,
output_path: &Path,
key: Option<&str>,
interactive: bool,
) -> Result<()>
pub fn emit_answers( &self, plan: &SetupPlan, output_path: &Path, key: Option<&str>, interactive: bool, ) -> Result<()>
Emit an answers template JSON file.
Discovers all packs in the bundle and generates a template with all
setup questions. Users fill this in and pass it via --answers.
Sourcepub fn load_answers(
&self,
answers_path: &Path,
key: Option<&str>,
interactive: bool,
) -> Result<LoadedAnswers>
pub fn load_answers( &self, answers_path: &Path, key: Option<&str>, interactive: bool, ) -> Result<LoadedAnswers>
Load answers from a JSON/YAML file.