pub fn build_sectioned_flow(
form_spec: &FormSpec,
sections: &[FlowSection],
) -> QAFlowSpecExpand description
Build a section-based QAFlowSpec where questions are grouped into named sections with message headers and decision gates.
pub fn build_sectioned_flow(
form_spec: &FormSpec,
sections: &[FlowSection],
) -> QAFlowSpecBuild a section-based QAFlowSpec where questions are grouped into named sections with message headers and decision gates.