pub fn generate_secret_value(spec: &GeneratedSecretSpec) -> Result<String>Expand description
Generate the value for a declared secret according to its policy.
pub fn generate_secret_value(spec: &GeneratedSecretSpec) -> Result<String>Generate the value for a declared secret according to its policy.