Module gtbundle

Module gtbundle 

.gtbundle archive format support.

A .gtbundle file is an archive containing a complete Greentic bundle. Supports both SquashFS (default) and ZIP formats.

Format

my-bundle.gtbundle (SquashFS or ZIP archive)
├── greentic.demo.yaml or bundle.yaml
├── packs/
├── providers/
├── resolved/
├── state/
└── tenants/

Enums

BundleFormat
Archive format for gtbundle files.

Functions

create_gtbundle
Create a .gtbundle archive from a bundle directory using the default format.
create_gtbundle_with_format
Create a .gtbundle archive with a specific format.
detect_bundle_format
Detect the format of a gtbundle file by reading its magic bytes.
extract_gtbundle
Extract a .gtbundle archive to a directory.
extract_gtbundle_to_temp
Extract a .gtbundle to a temporary directory and return the path.
is_gtbundle_dir
Check if a path is a .gtbundle directory (named *.gtbundle but is a dir).
is_gtbundle_file
Check if a path is a .gtbundle archive file.