pub fn detect_bundle_format(path: &Path) -> Result<BundleFormat>Expand description
Detect the format of a gtbundle file by reading its magic bytes.
pub fn detect_bundle_format(path: &Path) -> Result<BundleFormat>Detect the format of a gtbundle file by reading its magic bytes.