pub struct SetupInputAnswers { /* private fields */ }Expand description
Answers loaded from a user-provided --setup-input file.
Implementations
Sourceimpl SetupInputAnswers
impl SetupInputAnswers
Sourcepub fn new(raw: Value, provider_keys: BTreeSet<String>) -> Result<Self>
pub fn new(raw: Value, provider_keys: BTreeSet<String>) -> Result<Self>
Creates a new helper with the raw file data and the set of known provider IDs.
Sourcepub fn answers_for_provider(&self, provider: &str) -> Option<&Value>
pub fn answers_for_provider(&self, provider: &str) -> Option<&Value>
Returns the answers that correspond to a provider/pack.
If the raw value is keyed by provider ID, returns only that provider’s answers. Otherwise, returns the entire raw value (flat mode).