CLI command implementations for greentic-setup.
Functions
- add
- Add a pack to a bundle.
- build
- Build a portable bundle archive.
- doctor
- execute_
pending_ oauth_ device_ actions - init
- Initialize a new bundle directory.
- list
- List packs in a bundle.
- print_
pending_ setup_ actions - remove
- Remove a provider from a bundle.
- setup
- Run the setup command.
- setup_
migrate - Migrate legacy setup backend state to the generic setup state location.
- setup_
next - Inspect and record the next provider backend-contract setup step.
- setup_
reset - Reset persisted setup state for a provider backend contract.
- setup_
retry - Clear retry-blocking state for a provider backend-contract setup step.
- setup_
status - Show persisted setup status for a provider backend contract.
- status
- Show bundle status.
- update
- Run the update command.
- wait_
for_ pending_ oauth_ callbacks