Minimal JSON Schema validation for provider setup contracts.
This intentionally supports only the subset used by this crate’s setup schemas. It avoids adding a heavy dependency while still making doctor use the published schema files as the first validation layer.