pub fn register_webhook(
_provider_id: &str,
config: &Value,
_tenant: &str,
_team: Option<&str>,
) -> Option<Value>Expand description
Register a webhook for a provider based on its setup answers.
Returns Some(result) with status JSON from declared ops, or None if
the provider doesn’t declare webhook ops in its config. The actual webhook
registration is handled by the provider’s setup_webhook WASM operation,
invoked by the setup engine after this function returns None.